# Changelog

## 0.29.2 (2026-03-17)

Full Changelog: [v0.29.1...v0.29.2](https://github.com/cjavdev/spotted-py/compare/v0.29.1...v0.29.2)

### Bug Fixes

* **deps:** bump minimum typing-extensions version ([a4b87a3](https://github.com/cjavdev/spotted-py/commit/a4b87a382e013f3470d15dff211f3f117863796a))

## 0.29.1 (2026-03-17)

Full Changelog: [v0.29.0...v0.29.1](https://github.com/cjavdev/spotted-py/compare/v0.29.0...v0.29.1)

### Bug Fixes

* **pydantic:** do not pass `by_alias` unless set ([31c0fe3](https://github.com/cjavdev/spotted-py/commit/31c0fe341d9a5daf58b2ca2891191e2178f49c87))


### Chores

* **ci:** bump uv version ([a60f457](https://github.com/cjavdev/spotted-py/commit/a60f4572482ec57c53f822fbdb409fb8e84f2ebb))
* **ci:** skip uploading artifacts on stainless-internal branches ([ca1eb8b](https://github.com/cjavdev/spotted-py/commit/ca1eb8b2a7d1b7ea57ddfa9acd3780d54243e1dc))
* format all `api.md` files ([0c765a0](https://github.com/cjavdev/spotted-py/commit/0c765a0834316c9608d2e90cdf1604694a478ab0))
* **internal:** add request options to SSE classes ([35923f2](https://github.com/cjavdev/spotted-py/commit/35923f23dbd85ccadb99a87e25623ab97e52f773))
* **internal:** fix lint error on Python 3.14 ([1ad528a](https://github.com/cjavdev/spotted-py/commit/1ad528a08561a1cfb0baca91b485d5b665b576c6))
* **internal:** make `test_proxy_environment_variables` more resilient ([16f2319](https://github.com/cjavdev/spotted-py/commit/16f2319ffb13f13b8e32ca33a17e3c8bb710faf7))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([ab8ffff](https://github.com/cjavdev/spotted-py/commit/ab8ffffda62316d34ea0806e6f73999a81330b69))
* **internal:** remove mock server code ([7a2c1e6](https://github.com/cjavdev/spotted-py/commit/7a2c1e6e66d2e40b238b800966a20c073053428d))
* update mock server docs ([64f3993](https://github.com/cjavdev/spotted-py/commit/64f39936c62c933691f2cd205edaabd8c7098279))
* update placeholder string ([1c5cf1a](https://github.com/cjavdev/spotted-py/commit/1c5cf1af399dbfbe332377653fca710067e7fb8f))

## 0.29.0 (2026-02-12)

Full Changelog: [v0.28.0...v0.29.0](https://github.com/cjavdev/spotted-py/compare/v0.28.0...v0.29.0)

### Features

* **api:** api update ([73f04e1](https://github.com/cjavdev/spotted-py/commit/73f04e1d9165a5a0c51848b6db87abc3b9df0299))


### Chores

* **internal:** bump dependencies ([06a6cd9](https://github.com/cjavdev/spotted-py/commit/06a6cd9343d98622452d8239e150604ca9553950))

## 0.28.0 (2026-02-10)

Full Changelog: [v0.27.0...v0.28.0](https://github.com/cjavdev/spotted-py/compare/v0.27.0...v0.28.0)

### Features

* **api:** api update ([58d3dfa](https://github.com/cjavdev/spotted-py/commit/58d3dfa09e343bc410258837bb46af285a931e4e))

## 0.27.0 (2026-02-08)

Full Changelog: [v0.26.0...v0.27.0](https://github.com/cjavdev/spotted-py/compare/v0.26.0...v0.27.0)

### Features

* **api:** api update ([ac163ac](https://github.com/cjavdev/spotted-py/commit/ac163acc304a79983686c40efd3b2cde9f06ade9))

## 0.26.0 (2026-01-30)

Full Changelog: [v0.25.2...v0.26.0](https://github.com/cjavdev/spotted-py/compare/v0.25.2...v0.26.0)

### Features

* **client:** add custom JSON encoder for extended type support ([39da5f7](https://github.com/cjavdev/spotted-py/commit/39da5f79f73316c6b87fb0da7d29b7286c6f3042))

## 0.25.2 (2026-01-29)

Full Changelog: [v0.25.1...v0.25.2](https://github.com/cjavdev/spotted-py/compare/v0.25.1...v0.25.2)

### Bug Fixes

* **docs:** fix mcp installation instructions for remote servers ([9a609f5](https://github.com/cjavdev/spotted-py/commit/9a609f5c71c5b59e0c8f228af8e996b8325c03f2))


### Chores

* **ci:** upgrade `actions/github-script` ([3a7b4d8](https://github.com/cjavdev/spotted-py/commit/3a7b4d897b31180b7419c4c1cf3073c91d3464e5))

## 0.25.1 (2026-01-17)

Full Changelog: [v0.25.0...v0.25.1](https://github.com/cjavdev/spotted-py/compare/v0.25.0...v0.25.1)

### Chores

* **internal:** update `actions/checkout` version ([f7e7247](https://github.com/cjavdev/spotted-py/commit/f7e7247bc3677745e1329bdd13582f33aa677cd8))

## 0.25.0 (2026-01-15)

Full Changelog: [v0.24.0...v0.25.0](https://github.com/cjavdev/spotted-py/compare/v0.24.0...v0.25.0)

### Features

* **api:** manual updates ([af5c0d5](https://github.com/cjavdev/spotted-py/commit/af5c0d5bd25eea89919447e5d69cef98ca5eaa1a))
* **api:** manual updates ([b56b710](https://github.com/cjavdev/spotted-py/commit/b56b710b8a7a98b6c58f3d6c4ebbf34dc8f15a09))
* **api:** turn off oauth ([da51d4c](https://github.com/cjavdev/spotted-py/commit/da51d4ca819c28a02f7cc1a158c3355fc3b116d4))

## 0.24.0 (2026-01-14)

Full Changelog: [v0.23.0...v0.24.0](https://github.com/cjavdev/spotted-py/compare/v0.23.0...v0.24.0)

### Features

* **api:** api update ([63a5475](https://github.com/cjavdev/spotted-py/commit/63a547540d16193d5256d8a3796a85d6a7632e54))
* **client:** add support for binary request streaming ([0e4df6b](https://github.com/cjavdev/spotted-py/commit/0e4df6b66f8a6ac524284f24beaac246f87d09e8))

## 0.23.0 (2026-01-08)

Full Changelog: [v0.22.0...v0.23.0](https://github.com/cjavdev/spotted-py/compare/v0.22.0...v0.23.0)

### Features

* **api:** manual updates ([c6c5a84](https://github.com/cjavdev/spotted-py/commit/c6c5a841045d6155c5d374dca4293a7ae690c1e0))

## 0.22.0 (2026-01-08)

Full Changelog: [v0.21.0...v0.22.0](https://github.com/cjavdev/spotted-py/compare/v0.21.0...v0.22.0)

### Features

* **api:** manual updates ([260ee56](https://github.com/cjavdev/spotted-py/commit/260ee5601935c31ed3994aaccbd8ace96f6bb9c8))


### Refactors

* switch from rye to uv ([dcba363](https://github.com/cjavdev/spotted-py/commit/dcba363c8a4d15fe2db212838045660bdbb8645e))

## 0.21.0 (2026-01-08)

Full Changelog: [v0.20.0...v0.21.0](https://github.com/cjavdev/spotted-py/compare/v0.20.0...v0.21.0)

### Features

* **api:** oidc for python ([1856b26](https://github.com/cjavdev/spotted-py/commit/1856b261ef3d61071f9ce0d0abf90dc41fb221ca))

## 0.20.0 (2026-01-06)

Full Changelog: [v0.19.1...v0.20.0](https://github.com/cjavdev/spotted-py/compare/v0.19.1...v0.20.0)

### Features

* **api:** manual updates ([9d6c8b4](https://github.com/cjavdev/spotted-py/commit/9d6c8b47d8f23f5d281ae947c2fc43ef3e1f97bb))

## 0.19.1 (2026-01-06)

Full Changelog: [v0.19.0...v0.19.1](https://github.com/cjavdev/spotted-py/compare/v0.19.0...v0.19.1)

### Documentation

* prominently feature MCP server setup in root SDK readmes ([5b4f5ff](https://github.com/cjavdev/spotted-py/commit/5b4f5ff7b77c03e31286f1ede4efed7afd2c9978))

## 0.19.0 (2026-01-05)

Full Changelog: [v0.18.1...v0.19.0](https://github.com/cjavdev/spotted-py/compare/v0.18.1...v0.19.0)

### Features

* **api:** manual updates ([2918675](https://github.com/cjavdev/spotted-py/commit/291867521ab717f77dbe102bb0f4ce834bc596d6))

## 0.18.1 (2025-12-19)

Full Changelog: [v0.18.0...v0.18.1](https://github.com/cjavdev/spotted-py/compare/v0.18.0...v0.18.1)

### Chores

* **internal:** add `--fix` argument to lint script ([3d18b27](https://github.com/cjavdev/spotted-py/commit/3d18b27ecfce829aa4a48573c23a4361a2c12ecb))

## 0.18.0 (2025-12-18)

Full Changelog: [v0.17.0...v0.18.0](https://github.com/cjavdev/spotted-py/compare/v0.17.0...v0.18.0)

### Features

* **api:** manual updates ([9f7670f](https://github.com/cjavdev/spotted-py/commit/9f7670fb447c290afa08bec4c742a220b091a6b5))

## 0.17.0 (2025-12-18)

Full Changelog: [v0.16.2...v0.17.0](https://github.com/cjavdev/spotted-py/compare/v0.16.2...v0.17.0)

### Features

* **api:** manual updates ([25eb4e2](https://github.com/cjavdev/spotted-py/commit/25eb4e2ce836c23cf3634060d502c3de2edb4076))

## 0.16.2 (2025-12-18)

Full Changelog: [v0.16.1...v0.16.2](https://github.com/cjavdev/spotted-py/compare/v0.16.1...v0.16.2)

### Bug Fixes

* use async_to_httpx_files in patch method ([4089eec](https://github.com/cjavdev/spotted-py/commit/4089eec5269ef828aeeb400e45cd1f7c8a0843a1))

## 0.16.1 (2025-12-17)

Full Changelog: [v0.16.0...v0.16.1](https://github.com/cjavdev/spotted-py/compare/v0.16.0...v0.16.1)

### Chores

* speedup initial import ([09883dd](https://github.com/cjavdev/spotted-py/commit/09883ddda64c909c008366377a4d6f766d8cace1))

## 0.16.0 (2025-12-16)

Full Changelog: [v0.15.0...v0.16.0](https://github.com/cjavdev/spotted-py/compare/v0.15.0...v0.16.0)

### Features

* **api:** manual updates ([73ed615](https://github.com/cjavdev/spotted-py/commit/73ed6159327f9ae4b34a855d47b6eb24a557ebfb))

## 0.15.0 (2025-12-16)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/cjavdev/spotted-py/compare/v0.14.0...v0.15.0)

### Features

* **api:** manual updates ([a906b51](https://github.com/cjavdev/spotted-py/commit/a906b511ececf35eddf6a69ffc561c9cd9560ac2))

## 0.14.0 (2025-12-16)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/cjavdev/spotted-py/compare/v0.13.0...v0.14.0)

### Features

* **api:** manual updates ([a23f4ca](https://github.com/cjavdev/spotted-py/commit/a23f4caf69a8b57e67d18afd57fdaefbe4dbf1e9))


### Chores

* **internal:** add missing files argument to base client ([c2909d5](https://github.com/cjavdev/spotted-py/commit/c2909d5faca376da921d7393f153fc27667bf263))

## 0.13.0 (2025-12-10)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/cjavdev/spotted-py/compare/v0.12.0...v0.13.0)

### Features

* **api:** manual updates ([2b9f2a0](https://github.com/cjavdev/spotted-py/commit/2b9f2a037201872f23f5e8f103511b5f6b1ad9ed))

## 0.12.0 (2025-12-10)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/cjavdev/spotted-py/compare/v0.11.0...v0.12.0)

### Features

* **api:** manual updates ([969936e](https://github.com/cjavdev/spotted-py/commit/969936e19b3e6e61ae3b142efd44f13e93bfbd82))

## 0.11.0 (2025-12-10)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/cjavdev/spotted-py/compare/v0.10.0...v0.11.0)

### Features

* **api:** manual updates ([0fe77c7](https://github.com/cjavdev/spotted-py/commit/0fe77c7c17e8d9ac0d1cd973a1469c21fda40a58))

## 0.10.0 (2025-12-10)

Full Changelog: [v0.9.2...v0.10.0](https://github.com/cjavdev/spotted-py/compare/v0.9.2...v0.10.0)

### Features

* **api:** manual updates ([97d62e2](https://github.com/cjavdev/spotted-py/commit/97d62e2ea21e727d6d4953f160fc9232d8cc44bf))

## 0.9.2 (2025-12-09)

Full Changelog: [v0.9.1...v0.9.2](https://github.com/cjavdev/spotted-py/compare/v0.9.1...v0.9.2)

### Chores

* add missing docstrings ([e01099a](https://github.com/cjavdev/spotted-py/commit/e01099a2459a9383438802b778f66d79102faf89))

## 0.9.1 (2025-12-09)

Full Changelog: [v0.9.0...v0.9.1](https://github.com/cjavdev/spotted-py/compare/v0.9.0...v0.9.1)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([b9f9c2f](https://github.com/cjavdev/spotted-py/commit/b9f9c2fa5bfa695fe43985ddb56c3821542e5374))

## 0.9.0 (2025-12-05)

Full Changelog: [v0.8.1...v0.9.0](https://github.com/cjavdev/spotted-py/compare/v0.8.1...v0.9.0)

### Features

* **api:** Update readme titles. ([bb3dfe4](https://github.com/cjavdev/spotted-py/commit/bb3dfe4e9f61dc02aa184d9f3a40dc141b349476))


### Chores

* update lockfile ([042c44c](https://github.com/cjavdev/spotted-py/commit/042c44cd6915f9648639c331f9377cd7b7a7f276))

## 0.8.1 (2025-11-28)

Full Changelog: [v0.8.0...v0.8.1](https://github.com/cjavdev/spotted-py/compare/v0.8.0...v0.8.1)

### Bug Fixes

* ensure streams are always closed ([2194393](https://github.com/cjavdev/spotted-py/commit/219439326768c39e40889229acb53da55a982513))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([89caa9c](https://github.com/cjavdev/spotted-py/commit/89caa9c6b807bd9343aaa0f6f324f1447f80bc78))

## 0.8.0 (2025-11-26)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/cjavdev/spotted-py/compare/v0.7.0...v0.8.0)

### Features

* **api:** manual updates ([b652327](https://github.com/cjavdev/spotted-py/commit/b652327891d1d5d7ee2e897c980dfd0fdf6f5337))
* **api:** manual updates ([2cac07d](https://github.com/cjavdev/spotted-py/commit/2cac07da2470d5ff47fec8b0ab75785653f9197d))


### Chores

* add Python 3.14 classifier and testing ([0efd78a](https://github.com/cjavdev/spotted-py/commit/0efd78a9e9ce1f1d48942d50b1da024adfeea782))

## 0.7.0 (2025-11-20)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/cjavdev/spotted-py/compare/v0.6.0...v0.7.0)

### Features

* **api:** manual updates ([6eb6bf7](https://github.com/cjavdev/spotted-py/commit/6eb6bf78cfcc64fb4de44cd1fd2662ee2fb24a81))

## 0.6.0 (2025-11-20)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/cjavdev/spotted-py/compare/v0.5.0...v0.6.0)

### Features

* **api:** manual updates ([93d44d4](https://github.com/cjavdev/spotted-py/commit/93d44d4c25f09433ba82b5dc6a42eabd979ada4b))

## 0.5.0 (2025-11-20)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/cjavdev/spotted-py/compare/v0.4.0...v0.5.0)

### Features

* **api:** manual updates ([f0ac812](https://github.com/cjavdev/spotted-py/commit/f0ac8127edd6617494dbe1cfeda02dfb1625a489))
* **api:** rename public to published for java ([114661e](https://github.com/cjavdev/spotted-py/commit/114661e6517185d0a30a1117d65537350f47dbdd))

## 0.4.0 (2025-11-20)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/cjavdev/spotted-py/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates ([6e6dd96](https://github.com/cjavdev/spotted-py/commit/6e6dd969a1167eeb833e8e92bfd9593640edaea2))

## 0.3.0 (2025-11-20)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/cjavdev/spotted-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** manual updates ([7fcfe44](https://github.com/cjavdev/spotted-py/commit/7fcfe449b00fc37d9e898c7e1966d31d8951909e))

## 0.2.0 (2025-11-19)

Full Changelog: [v0.1.1...v0.2.0](https://github.com/cjavdev/spotted-py/compare/v0.1.1...v0.2.0)

### Features

* **api:** manual updates ([e143794](https://github.com/cjavdev/spotted-py/commit/e143794da0c71c2e387720a971365a76ebe18b0d))

## 0.1.1 (2025-11-19)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/cjavdev/spotted-py/compare/v0.1.0...v0.1.1)

## 0.1.0 (2025-11-18)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/cjavdev/spotted-py/compare/v0.0.1...v0.1.0)

### Features

* **api:** add mode constants ([fe70b6e](https://github.com/cjavdev/spotted-py/commit/fe70b6e677b8f98b322ede5472f8d4b1b13fb7bb))
* **api:** Adds custom helper for datetime conversion ([f0af8af](https://github.com/cjavdev/spotted-py/commit/f0af8afa4464c570a6f9d5e9399e85b981fca073))
* **api:** manual updates ([5c1e5ab](https://github.com/cjavdev/spotted-py/commit/5c1e5ab2a28773a2ead1a2fdcd317d6d9b09e906))
* **api:** manual updates ([dc95eba](https://github.com/cjavdev/spotted-py/commit/dc95ebac61d03d6efc285deed1bf9f33aa2589fe))
* **api:** manual updates ([f41e552](https://github.com/cjavdev/spotted-py/commit/f41e552da24806e9b515666fb0cbc3210f5d1a29))
* **api:** manual updates ([a514df1](https://github.com/cjavdev/spotted-py/commit/a514df15645be8ff106a7e20878e7c2d86fbdd1e))
* **api:** manual updates ([93de3c8](https://github.com/cjavdev/spotted-py/commit/93de3c88aa02793b460728c85dd3799effb9fecd))
* **api:** manual updates ([8c0849b](https://github.com/cjavdev/spotted-py/commit/8c0849b67194ae3df5f5d7cc447990ad26390ed8))
* **api:** manual updates ([8629913](https://github.com/cjavdev/spotted-py/commit/8629913995e32220a2c4071dfb0ba317b2fb4c5f))
* **api:** manual updates ([269750a](https://github.com/cjavdev/spotted-py/commit/269750ad5aa66cea4771475fb52dfe3697d04664))
* **api:** manual updates ([bd0d036](https://github.com/cjavdev/spotted-py/commit/bd0d036467ee7e14f10b60f47fa0566116f2a4d3))
* **api:** manual updates ([756bf99](https://github.com/cjavdev/spotted-py/commit/756bf99c5d078381f75483e2c3178b7848a7ff30))
* **api:** manual updates ([33cb4d6](https://github.com/cjavdev/spotted-py/commit/33cb4d667533e3fb999c40e524e30f47e0667f33))
* **api:** manual updates ([5bbf5b7](https://github.com/cjavdev/spotted-py/commit/5bbf5b73cca26561170cf225b6514fdcd1de6e0d))
* **api:** manual updates ([97307b9](https://github.com/cjavdev/spotted-py/commit/97307b9a3cf8f9ad3026d9e8ceba887caf776c3a))
* **api:** manual updates ([bbdbaaf](https://github.com/cjavdev/spotted-py/commit/bbdbaafeb0c9bb55c9b5247ed4dd6c787911adcd))
* **api:** manual updates ([1769b1d](https://github.com/cjavdev/spotted-py/commit/1769b1d49bf18b106af7138217cfb236d29f1f59))
* **api:** manual updates ([4a52d9c](https://github.com/cjavdev/spotted-py/commit/4a52d9c18970a62a6baa32ab98850ef6db59b4d2))


### Bug Fixes

* **client:** close streams without requiring full consumption ([2201b8f](https://github.com/cjavdev/spotted-py/commit/2201b8f6ad6095a3d536326bb632b84611910ec2))
* compat with Python 3.14 ([fa79197](https://github.com/cjavdev/spotted-py/commit/fa79197ad033922d3cbf1cb25a9906fdc09c8c75))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([4775114](https://github.com/cjavdev/spotted-py/commit/477511475b7a83e098fd0b9849d69724b579a26d))


### Chores

* configure new SDK language ([d2c56e0](https://github.com/cjavdev/spotted-py/commit/d2c56e00920aab81e56b19a8f4d2463047a7c0e5))
* **internal/tests:** avoid race condition with implicit client cleanup ([f33ff4f](https://github.com/cjavdev/spotted-py/commit/f33ff4f7c2414a6fcdc4378fafa5b830ce1bfc82))
* **internal:** grammar fix (it's -&gt; its) ([d6b679c](https://github.com/cjavdev/spotted-py/commit/d6b679c4c2895082af59daa3e565db90ac895bf9))
* **package:** drop Python 3.8 support ([a193e78](https://github.com/cjavdev/spotted-py/commit/a193e78635771ec3644b2001979675318ba2f638))
* update SDK settings ([d62d40f](https://github.com/cjavdev/spotted-py/commit/d62d40ff0735d6064bf4c0c23222bb7a5e4540c5))
* update SDK settings ([9cfbf8a](https://github.com/cjavdev/spotted-py/commit/9cfbf8a1247c8e94ac4b6460d59539673c31fe16))
